<?php
/**
 * Plugin Name:BuddyPress Activity Comment Notifier
 * Author: Brajesh Singh
 * Author URI:http://buddydev.com/members/sbrajesh
 * Description: Show facebook like notification in the notification drop down when some user comment on your update or on other users update where you have commented
 * Version 1.0
 * License: GPL
 * Date Updated: 3rd December, 2010
 * 
 */
/**
 * Special desclaimer: BuddyPress does not allows multiple items from same component with similar action(It is grouped by buddypress before delivering to the notfication formatting function), so I have hacked the component_action to be unique per item, because we want update for individual action items
 * Another hack is, buddypress activity format function is not declared as of buddypress 1.2.7/1.3 branch, so I am supplying a custom format function. The day it is added to buddypress, we will change it :)
 * Most important: It is just for fun :) hope you would like it
 */

/**
 *
 * @global <type> $bp
 * @global <type> $wpdb
 * @param <type> $activity_id
 * @return <type>
 * @desc: find all the unique user_id who have commented on this activity
 */
function ac_notify_find_involved_persons($activity_id){
    global $bp,$wpdb;
    $sql="select DISTINCT(user_id) from {$bp->activity->table_name} where item_id=%d and user_id!=%d ";
    $users=$wpdb->get_col($wpdb->prepare($sql,$activity_id,$bp->loggedin_user->id));//it finds all uses who commted on the activity
     return $users;
}

//notify all the users who have commented, or who was the original poster of the update, when someone comments
//hook to activity_comment_posted action
add_action("bp_activity_comment_posted","ac_notify_notify",10,2);
 function ac_notify_notify($comment_id, $params){
   global $bp;
   extract( $params );

   $users=ac_notify_find_involved_persons($activity_id);
   $activity=new BP_Activity_Activity($activity_id);
   //pus the original poster user_id, if the original poster has not commented on his/her status yet
   if(!in_array($activity->user_id, $users)&&($bp->loggedin_user->id!=$activity->user_id))//if someone else is commenting
       array_push ($users, $activity->user_id);
   
    foreach((array)$users as $user_id){
               //create a notification
               bp_core_add_notification( $activity_id, $user_id, $bp->activity->id, 'new_activity_comment_'.$activity_id );//a hack to not allow grouping by component,action, rather group by component and individual action item
           }
       }

/** since buddypress does not supplies an activity format function, I am suppllying a custom one :)
 *
 * @global  $bp
 * @param <type> $action
 * @param <type> $activity_id
 * @param <type> $secondary_item_id
 * @param <type> $total_items
 * @return <type>
 */
function bp_activity_format_notifications( $action, $activity_id, $secondary_item_id, $total_items ) {
   
	global $bp;
        $user_names=array();
        $link=bp_activity_get_permalink( $activity_id );
        $activity = new BP_Activity_Activity( $activity_id );
       //if it is the original poster, say your, else say %s's post
        
        if($activity->user_id==$bp->loggedin_user->id){
                $text=__("your");
                $also="";
        }
        else{
          $text=sprintf(__("%s's"),  bp_core_get_user_displayname ($activity->user_id));//somone's
          $also=" also";
          
        }
        $ac_action='new_activity_comment_'.$activity_id;
     	if($action==$ac_action){
	//if ( (int)$total_items > 1 ) {
             $users=ac_notify_find_involved_persons($activity_id);
               $total_user= $count=count($users);//how many unique users have commented
                if($count>2){
                    $users=array_slice($users, $count-2);//just show name of two poster, rest should be as and 'n' other also commeted
                $count=$count-2;
                $glue=", ";
                }
                else if($total_user==2)
                    $glue=" and ";//if there are 2 unique users , say x and y commented

                foreach((array)$users as $user_id)
                    $user_names[]=bp_core_get_user_displayname ($user_id);
                
                if(!empty($user_names))
                     $commenting_users=join ($glue, $user_names);
                   
                
                if($total_user>2)
                    $text=$commenting_users." and ".$count." others".$also." commented on ".$text. " post";//can we change post to some meaningfull thing depending on the activity item ?
                else
                   $text=$commenting_users.$also ." commented on ".$text. " post";

                //sprintf( __('%s commented on your update' ),$commenting_users)
                return apply_filters( 'bp_activity_multiple_new_comment_notification', '<a href="' . $link. '">' . $text . '</a>');
		

	
        }
	return false;
}

 //for removing the notification if the single permalink screen is opened
add_action("bp_activity_screen_single_activity_permalink","ac_notify_remove_notification",10,2);
function ac_notify_remove_notification($activity,$has_access){
    global $bp;
if($has_access)//if user can view this activity, remove notification(just a safeguard for hidden activity)
    bp_core_delete_notifications_for_user_by_item_id(  $bp->loggedin_user->id, $activity->id, $bp->activity->id,  'new_activity_comment_'.$activity->id);
    
}
?>